@@ -94,7 +94,7 @@ class RawCell(BaseRawCell):
 
     @property
     def is_date(self):
-        return is_date_format(self.number_format)
+        return self.data_type == Cell.TYPE_NUMERIC and is_date_format(self.number_format)
 
 def get_range_boundaries(range_string, row_offset=0, column_offset=1):
 
@@ -125,11 +125,10 @@ def get_missing_cells(row, columns):
 
 class IterableWorksheet(Worksheet):
 
-    def __init__(self, parent_workbook, title, workbook_name,
-            sheet_codename, xml_source, string_table, style_table):
+    def __init__(self, parent_workbook, title, sheet_codename, xml_source,
+                 string_table, style_table):
 
         Worksheet.__init__(self, parent_workbook, title)
-        self._workbook_name = workbook_name
         self._sheet_codename = sheet_codename
         self._string_table = string_table
         self._style_table = style_table
