@@ -75,13 +75,14 @@ def read_dimension(xml_source):
             if min_row is None:
                 min_row = int(row)
             span = el.get("spans")
-            start, stop = span.split(":")
-            if min_col is None:
-                min_col = int(start)
-                max_col = int(stop)
-            else:
-                min_col = min(min_col, int(start))
-                max_col = max(max_col, int(stop))
+            if ":" in span:
+                start, stop = span.split(":")
+                if min_col is None:
+                    min_col = int(start)
+                    max_col = int(stop)
+                else:
+                    min_col = min(min_col, int(start))
+                    max_col = max(max_col, int(stop))
     max_row = int(row)
     warn("Unsized worksheet")
     return get_column_letter(min_col), min_row, get_column_letter(max_col),  max_row
@@ -117,6 +118,7 @@ class WorkSheetParser(object):
             tag_name = element.tag
             if tag_name in dispatcher:
                 dispatcher[tag_name](element)
+                element.clear()
 
 
     def parse_cell(self, element):
@@ -302,12 +304,12 @@ def fast_parse(ws, xml_source, string_table, style_table, color_index=None):
 
 
 def read_worksheet(xml_source, parent, preset_title, string_table,
-                   style_table, color_index=None, workbook_name=None, sheet_codename=None, keep_vba=False):
+                   style_table, color_index=None, sheet_codename=None, keep_vba=False):
     """Read an xml worksheet"""
-    if workbook_name and sheet_codename:
+    if sheet_codename:
         from openpyxl.reader.iter_worksheet import IterableWorksheet
-        ws = IterableWorksheet(parent, preset_title, workbook_name,
-                sheet_codename, xml_source, string_table, style_table)
+        ws = IterableWorksheet(parent, preset_title, sheet_codename,
+                               xml_source, string_table, style_table)
     else:
         ws = Worksheet(parent, preset_title)
         fast_parse(ws, xml_source, string_table, style_table, color_index)
